Command Line Utility — PySqueezeCenter v0.93 documentation

### Navigation

- index
- previous |
- PySqueezeCenter v0.93 documentation »

# Command Line Utility

Help:

    Usage: pysqueezecenter or type pysqueezecenter -h (--help) for help

    Options:
      --version             show program's version number and exit
      -h, --help            show this help message and exit
      -v                    Verbosity. Add more -v to be more verbose
                            (4=DEBUG,3=INFO,2=WARNING,1=ERROR,0=CRITICAL)
                            [default: 3]
      -l LOGFILE, --logfile=LOGFILE
                            Log to file instead of console
      -s HOST, --host=HOST  Specify Hostname of SqueezeCenter [default: localhost]
      -n PORT, --port=PORT  Specify Port of SqueezeCenter [default: 9090]
      -u USERNAME, --username=USERNAME
                            Specify Authorisation Username
      -p PASSWORD, --password=PASSWORD
                            Specify Authorisation Password
      -d DEVICE, --device=DEVICE
                            Specify SqueezePlayer Device MAC Address

### Navigation

- index
- previous |
- PySqueezeCenter v0.93 documentation »